C  Solve for uniform flow in the upstream channel when this channel flows into
C a steep downstream channel.  The downstream channel (which has critical flow
C at its entrance) may be trapezoidal or circular.  The three equations being
C  solved are: (1) Energy across transition, (2) Critical Flow, and (3) Uniform
C flow in upstream channel.
       INTEGER*2 INDX(3)
       REAL F(3),FF(3),DD(3,3)
       COMMON X(3),B1,FM1,SO,B2,FM2,D,G,G2,FKL,ITYPE,P1,T2,D4,FMS
       EQUIVALENCE (Q,X(1)),(Y1,X(2)),(Y2,X(3))
       WRITE(*,*)' Is downstream steep channel: (1) trap, (2) circular'
       READ(*,*) ITYPE
       WRITE(*,*)' For upst. Ch. give: b,m,n,So,KL,g'
       READ(*,*) B1,FM1,FN,SO,FKL,G
       FMS=2.*SQRT(FM1*FM1+1.)
       FKL=1.+FKL
       G2=2.*G
       Cu=1.486
       IF(G.LT.20.) Cu=1.
       IF(ITYPE.EQ.1) THEN
       WRITE(*,*)' For downst. Ch. give: b,m'
       READ(*,*) B2,FM2
       ELSE
       WRITE(*,*)' For downst. Ch. give: D'
       READ(*,*) D
       D4=.25*D*D
       ENDIF
       WRITE(*,*)' Give guesses for: Q,Y1 & Yc2'
       READ(*,*) X
       SO=SQRT(SO)*Cu/FN
       NCT=0
10     CALL FUN(F)
       DO 20 I=1,3
       XX=X(I)
       X(I)=1.005*X(I)
       CALL FUN(FF)
       DO 15 J=1,3
15     DD(J,I)=(FF(J)-F(J))/(X(I)-XX)
20     X(I)=XX
       CALL SOLVEQ(3,1,3,DD,F,1,DET,INDX)
       SUM=0.
       DO 25 I=1,3
       X(I)=X(I)-F(I)
25     SUM=SUM+ABS(F(I))
       NCT=NCT+1
       WRITE(*,*) ' NCT=',NCT,SUM
       IF(SUM.GT. .001 .AND.NCT.LT.30) GO TO 10
       WRITE(*,100) X
100    FORMAT(' Solution: Q=',F9.2,' Y1=',F9.3,' Y2=Yc=',F9.3)
       END
       SUBROUTINE FUN(F)
       REAL F(3)
       COMMON X(3),B1,FM1,SO,B2,FM2,D,G,G2,FKL,ITYPE,P1,T2,D4,FMS
       A1=AREA(1)
       A2=AREA(2)
       F(1)=X(2)+(X(1)/A1)**2/G2-X(3)-FKL*(X(1)/A2)**2/G2
       F(2)=X(1)**2*T2/(G*A2**3)-1.
       F(3)=X(1)-So*A1*(A1/P1)**.6666667
       RETURN
       END
       FUNCTION AREA(K)
       COMMON X(3),B1,FM1,SO,B2,FM2,D,G,G2,FKL,ITYPE,P1,T2,D4,FMS
       IF(K.EQ.1) THEN
       P1=B1+FMS*X(2)
       AREA=(B1+FM1*X(2))*X(2)
       ELSE
       IF(ITYPE.EQ.1) THEN
       T2=B2+2.*FM2*X(3)
       AREA=(B2+FM2*X(3))*X(3)
       ELSE
       BETA=ACOS(1.-2.*X(3)/D)
       T2=D*SIN(BETA)
       AREA=D4*(BETA-COS(BETA)*SIN(BETA))
       ENDIF
       ENDIF
       RETURN
       END