% This script is designed to solve channel problems in which there is
% lateral inflow into a non-prismatic channel.  It is similar to program
% APPCRUK.FOR given in Appendix C, but rather than calling on the Runge-
% Kutta ODE solver it utilizes the MATLAB built-in ODE solver ode45.
% Notice the function yprime is used to supply dY/dx which includes
% arguments for lateral input and non prismatic channels
% To solve the Problem given in Appendix C after the listing of APPCRUK.FOR
% the following input would be given:
%Give the following input values
%Qo = 400
%qs = 1
%Uq = 0
%Bo = 10
%Db = 0
%Fmo = 1
%Dm = 0
%So = .0008
%n = .013
%beg x = 0
%end x = 50
%DELX = 5
%YBEG = 4
%g = 32.2
% In this script the increment for delta x is given as input, so that no
% like script control over the number of lines in the output occurs.  This
% is accomplished by using the MATLAB linspace to provide the vector of x's
% for which the solution is to be obtained.
disp('Give the following input values');
 Qo=input('Qo = '); qs=input('qs = '); Uq=input('Uq = ');
 Bo=input('Bo = '); Db=input('Db = '); FMo=input('Fmo = ');
 Dm=input('Dm = '); SO=input('So = '); FN=input('n = ');
XBEG=input('beg x = '); XEND=input('end x = '); DELX=input('DELX = '); 
YBEG=input('YBEG = ');  g=input('g = ');  
if g<25.
    g=Cu;
else
    Cu=1.486;
end
fid=input('Should output be written to file? (2=yes,1=no)');
if fid>1 
    FILN=input('Give name of this file ');
    fid=fopen(FILN,'w');
end
Y(1)=YBEG; NS=abs(XEND-XBEG)/abs(DELX);
fprintf(fid,'      x          Y         Q          Area    Momentum       Fr\n');
    [xx,yy]=ode45(@yprime,linspace(XBEG,XEND,NS),[Y(1)]',[],Bo,FMo,FN,SO,Qo,...
        qs,Uq,Db,Dm,g,Cu);
    nn=size(xx);
    for i=1:nn(1)
        B=Bo+Db*xx(i); FM=FMo+Dm*xx(i); Q=Qo+qs*xx(i);
        A=(B+FM*yy(i))*yy(i); FMOM=(B/2+FM*yy(i)/3)*yy(i)^2+Q*Q/A/g;
        Fr=sqrt(Q*Q*(B+2*FM*yy(i))/(g*A^3));
        fprintf(fid,'%10.3f %10.3f %10.3f %10.2f %10.2f %10.2f\n',xx(i),...
            yy(i),Q,A,FMOM,Fr);
    end