% This script is designed to solve channel problems in which there is
% lateral inflow into a non-prismatic channel.  It is similar to program
% APPCRUK.FOR given in Appendix C, and calls on the Runge-Kutta ODE solver
% ruku4a.m that converts this Fortran SUBROUTINE to a MATHLAB function.
% in order to pass parameters from this main script to the function gyprime
% these are declared "global". The same "global" declaration is in gyprime.
% Notice the function gyprime is used to supply dY/dx which includes
% variables for lateral input and non prismatic channels just as does
% function yprime.  The difference is the "global" declaration.
% To solve the Problem given in Appendix C after the listing of APPCRUK.FOR
% the following input would be given:
%Give the following input values
%Qo = 400
%qs = 1
%Uq = 0
%Bo = 10
%Db = 0
%Fmo = 1
%Dm = 0
%So = .0008
%n = .013
%beg x = 0
%end x = 50
%DELX = 2
%YBEG = 4
%g = 32.2
% The solution will be given on the increment of delta x that ode45 choses
global Bo FMo FN SO Qo qs Uq Db Dm g Cu
disp('Give the following input values');
 Qo=input('Qo = '); qs=input('qs = '); Uq=input('Uq = ');
 Bo=input('Bo = '); Db=input('Db = '); FMo=input('Fmo = ');
 Dm=input('Dm = '); SO=input('So = '); FN=input('n = ');
XBEG=input('beg x = '); XEND=input('end x = '); DELX=input('DELX =');
YBEG=input('YBEG = ');  g=input('g = ');  
if g<25.
    g=Cu;
else
    Cu=1.486;
end
num=abs(XEND-XBEG)/abs(DELX)+1; 
fid=input('Should output be written to file? (2=yes,1=no)');
if fid>1 
    FILN=input('Give name of this file ');
    fid=fopen(FILN,'w');
end
X=XBEG:DELX:XEND; Y=zeros(1,num); yo=YBEG; Y(1)=YBEG; YTT=YBEG;
head='      x          Y         Q          Area    Momentum        Fr\n';
fprintf(fid,head);
for i=2:num
    Y(i)=rukust(@gyprime,1,DELX,X(i),X(i)+DELX,1.E-4,yo);  yo=Y(i);
end
for i=1:num
   B=Bo+Db*X(i); FM=FMo+Dm*X(i); Q=Qo+qs*X(i);
   A=(B+FM*Y(i))*Y(i); FMOM=(B/2+FM*Y(i)/3)*Y(i)^2+Q*Q/A/g;
   Fr=sqrt(Q*Q*(B+2*FM*Y(i))/(g*A^3));
   fprintf(fid,'%10.3f %10.3f %10.3f %10.2f %10.2f %10.2f\n',X(i),...
       Y(i),Q,A,FMOM,Fr);
end