% This script solves Example Problem 3 in Appendix B.  The approach used 
% is to first obtain a vector of x y values that defines the bottom of the 
% tank using MATLAB's built in ode45 to solve the ODE dy/dx=x+y/2.
% Thereafter the depths are integrated across the width of the tank using
% first the trapezoidal rule, and thereafter using Simpson's 1/3 rule.
% The 1st moment of area is then evaluated by multipling x times the depth
% at any position, and these products are integrated using Simpson's Rule.
wide=2.5074826; num=20;
delx=wide/num;  XB=0; delxh=delx/2;
X=0:delx:wide;
equat=inline('x+y/2','x','y');
[xx,yy]=ode45(equat,X,[YB]',[]);
n=size(yy);
% integrates using trapezoidal rule
area=0;  depth1=5+0.7071068*xx(1)-yy(1);
for i=2:num+1
    depth2=5+0.7071068*xx(i)-yy(i);
    area=area+delxh*(depth1+depth2);
    depth1=depth2;
end
disp(['Trapezoidal rule Area = ' num2str(area)]);
% integrates using Simpsons rule
area=0; delx3=delx/3; depth1=5+0.7071068*xx(1)-yy(1);
for i=2:2:num
    depth2=5+0.7071068*xx(i)-yy(i);
    depth3=5+0.7071068*xx(i+1)-yy(i+1);
    area=area+delx3*(depth1+4*depth2+depth3);
    depth1=depth3;
end
disp(['Simpson rule Area = ' num2str(area)]);
% Now compute first moments of areas using Simpson's rule
xarea=0;  xdepth1=xx(1)*(5+0.7071068*xx(1)-yy(1));
for i=2:2:num
    xdepth2=xx(i)*(5+0.7071068*xx(i)-yy(i));
    xdepth3=xx(i+1)*(5+0.7071068*xx(i+1)-yy(i+1));
    xarea=xarea+delx3*(xdepth1+4*xdepth2+xdepth3);
    xdepth1=xdepth3;
end
disp(['1st moments of Area = ' num2str(xarea)]);
disp(['Centroid Xc = ' num2str(xarea/area)]);
