% This script accomplishes the same tasks as the Fortran program
% in Appendix C under the heading "Runge-Kutta-Fehlberg Method"
% that illustrates the use of subroutine RKFEHLF with an example
% that asks that the equation dy/dx=exp(x)/Ln(y) be solved
% numerically, and then this solution be compared with the 
% exact solution.  In this script function rkfehlf is used to
% solve the ODE, but the built-in fsolve be used to obtain the
% exact solution for y.
error=1e-5; fmt='%7.2f %10.5f %10.5f\n';
x=0.1; y=1.4924887;
fyx=inline('y*(log(y)-1)-exp(x)+2','y','x');
options=optimset('display','off');
yexact=fsolve(fyx,y,options,x);
fprintf(1,fmt,x,y,yexact);
for i=1:19
    y=rkfehlf(inline('exp(x)/log(y)','x','y'),x,.1,y,error);
    x=x+.1;
    yexact=fsolve(fyx,y,options,x);
    fprintf(1,fmt,x,y,yexact);
end