% This function has been converted from the Fortran Subroutine RUKUST given
% in Appendix C.  It implements the Runge-Kutta method for solving a 
% system of ODE's, and finds the appropriate step size to satisfy the
% error condition.  Thus it calls the function ruku4s 3 times to decide
% whether the step size should be reduced, or increased.
% Notice in solving the in Appendix C (with APPCRUKd.m) it provides a
% solution in which the Froude number does not exceed unity, as does script
% APPCRUK.m, that uses ode45, whereas the solution from APPCRUKa, APPCRUKb
% APPCRUKc which don't adjust the step size produce supercritical flows.
function ytt=rukust(slope,n,dxs,xbeg1,xend1,error,y)
xbeg=xbeg1; xend=xend1; x1=xbeg; dx=dxs; icont=1; ii=0;
while (icont>0) & (ii<20)
    ii=ii+1;
    if icont<2
        yori=y;  x=x1;
        if abs(x+dx) > abs(xend)
            dx=xend-x;
        end
    end
    dx5=dx/2;  yy=y;
    y=ruku4s(slope,n,x,dx5,yy);
    yy=y;
    y=ruku4s(slope,n,x+dx5,dx5,yy);
    x1=x+dx;  yy=yori;
    yyt=ruku4s(slope,n,x,dx,yy);
    errm=0;
    for i=1:n
        yyt(i)=y(i)-yyt(i);
        if abs(y(i))<1.e-7
            ytty=0;
        else
            ytty=yyt(i)/y(i);
        end
        errm=max(errm,abs(ytty));
    end
    if errm==0
        dx=5.*dx;  dxs=dx; 
    else
        errm=errm/error;  
        dx=dx/errm^0.2;
        dxs=dx;
        if errm>1.0
            y=yori; 
            if abs(dx)>1.e-3
                icont=2;
            end
         end
    end
 if icont<2
     for i=1:n
      y(i)=y(i)+yyt(i)/15.;
     end
  end
    if abs(x1)>abs(xend)-1.e-8
        icont=0;
    end    
end
ytt=y';
        