% This function accomplishes the same task as the Fortran or C subroutine
% SIMPR.  It numerically evaluates the integral of the function defined by
% equat between the limits of XR and XE.  The default values for the error
% is ERR=0.0001, and the maximum divisions is MAX=20. The integration is 
% based on Simpson's rule.
function VALUE=simpr(equat,XB,XE,ERR,MAX,varargin)
f=fcnchk(equat); if nargin < 4 || isempty(ERR), ERR=1.e-5; end;
if nargin < 5 || isempty(MAX), MAX=20; end;
EV=-1.E30; 
VALU1=0.5*(XE-XB)*(f(XB)+f(XE));
M=1; I=0;  VALUE=VALU1;  EV1=VALU1; ICONT=1;
while (ICONT > 0) & (I < MAX)
  I=I+1;  DELX=(XE-XB)/M; X=XB+0.5*DELX; SUM=0.;
  for J=1:M
      SUM=SUM+f(X); X=X+DELX;
  end
  VALU1=0.5*(VALU1+(XE-XB)*SUM/M);
  M=2*M;
  VALUE=(4.*VALU1-EV1)/3.;
     if abs(VALUE-EV) < ERR*abs(EV)
         ICONT=0;
     end
      EV=VALUE; EV1=VALU1;
end
if I >= MAX
  disp([' Failed to satisfy error req.' num2str(VALUE-EV)]);
end