% This script is designed to solve the energy equation at a reservoir and
% the Mannings equation simultaneously, just as the program E_UN listed in
% the text.  It utilizes the MATLAB built-in function "fsolve" to solve the
% two simultaneous equations.  The dialog in the command window to solve
% Example Problem 12 in Chapter 2 follows.
%>>e_un
%Give: g,entrance loss coef,Ke & 0=trap,or 1=circle in [ ] [32.2 .2 0]
%  1  b
%  2  m
%  3  S
%  4  n
%  5  Q
%  6  H
%  7  Y
%Give two numbers for 2 unknown variables in [ ]: [5 7]
%Give values to variables
%1  b (known) = 8
%2  m (known) = 0
%3  S (known) = .00075
%4  n (known) = .014
%5  Q (guess) = 200
%6  H (known) = 5
%7  Y (guess) = 4.7
%Solution:
%  1 b =    8.0000
%  2 m =    0.0000
%  3 S = 0.0007500
%  4 n =    0.0140
%  5 Q =  175.9890
%  6 H =    5.0000
%  7 Y =    4.5678
  
cx='bmSnQHYK'; 
var=input('Give: g,entrance loss coef,Ke & 0=trap,or 1=circle in [ ] ');
g=var(1); FKe=(1+var(2))/(2*g); itype=var(3);  Cu=1; II=1:7; 
if itype>0, cx(1)='D';cx(2)=' ';  II(2)=[]; end;
if g>25, Cu=1.486; end;
for i=II
    fprintf(1,'%3.0f  %s\n',i,cx(i));
    ID(i)=0;
end
va1=input('Give two numbers for 2 unknown variables in [ ]: ');
ID(va1(1))=1; ID(va1(2))=1; disp('Give values to variables');
for i=II
    if ID(i)
        X(i)=input([num2str(i) '  ' cx(i) ' (guess) = ']);
    else
        X(i)=input([num2str(i) '  ' cx(i) ' (known) = ']);
    end
end
XU(1)=X(va1(1)); XU(2)=X(va1(2));
opt=optimset('display','off');
XU=fsolve('fe_un',XU,opt,itype,va1,Cu,FKe,X);
X(va1(1))=XU(1); X(va1(2))=XU(2);
fprintf(1,'Solution:\n');
for i=II
    if i==3
        fprintf('%3.0f %s =%10.7f\n',i,cx(i),X(i));
    else
        fprintf('%3.0f %s =%10.4f\n',i,cx(i),X(i));
    end
end
        
