% This script solves the three equation: (1) energy at reservoir, (2) Chezy's
% and (3) the Chezy C equations simultaneously, for any of two variables
% plus C.  It uses the function "fuenchez.m" to supply the equations, and
% the MATLAB built-in function "fsolve" to provide the solution.  The
% dialog in the command window to solve the second part of Example Problem
% 12 in Chapter 2, e.g. the trap. channel follows:
%>>uenchez
%Give: g,entrance loss coef,Ke,visc. & 0=trap,or 1=circle in [ ] [32.2 .1 1.41e-5 0]
%  1  b
%  2  m
%  3  S
%  4  e
%  5  Q
%  6  H
%  7  Y
%Give two numbers for 2 unknown variables in [ ]: [5 7]
%Give values to variables
%1  b (known) = 8
%2  m (known) = 1.2
%3  S (known) = .00075
%4  e (known) = .01
%5  Q (guess) = 300
%6  H (known) = 5
%7  Y (guess) = 4.7
%Solution:
% C =    112.780
%  1 b =    8.0000
%  2 m =    1.2000
%  3 S = 0.0007500
%  4 e =    0.0100
%  5 Q =  314.1610
%  6 H =    5.0000
%  7 Y =    4.5507
  
cx='bmSeQHY'; 
var=input('Give: g,entrance loss coef,Ke,visc. & 0=trap,or 1=circle in [ ] ');
g=var(1);FKe=(1+var(2))/(2*g);vis=var(3);itype=var(4);Cu=1;II=1:7;X(8)=90;
if itype>0, cx(1)='D';cx(2)=' ';  II(2)=[]; end;
if g>25, Cu=1.486; X(8)=130; end; cg=.221*vis/sqrt(g);g32=sqrt(32*g);
for i=II
    fprintf(1,'%3.0f  %s\n',i,cx(i));
    ID(i)=0;
end
va1=input('Give two numbers for 2 unknown variables in [ ]: ');
ID(va1(1))=1; ID(va1(2))=1; disp('Give values to variables');
for i=II
    if ID(i)
        X(i)=input([num2str(i) '  ' cx(i) ' (guess) = ']);
    else
        X(i)=input([num2str(i) '  ' cx(i) ' (known) = ']);
    end
end
XU(1)=X(va1(1)); XU(2)=X(va1(2)); XU(3)=X(8);
opt=optimset('display','off');
XU=fsolve('fuenchez',XU,opt,itype,va1,FKe,g32,cg,X);
X(va1(1))=XU(1); X(va1(2))=XU(2);
fprintf(1,'Solution:\n');
fprintf(1,' C = %10.3f\n',XU(3));
for i=II
    if i==3
        fprintf('%3.0f %s =%10.7f\n',i,cx(i),X(i));
    else
        fprintf('%3.0f %s =%10.4f\n',i,cx(i),X(i));
    end
end
