% This script is designed to solve for the conjugate depth across a
% hydraulic jump.  Either the upstream or downstream depth may be given as
% the known depth, and the other depth will be solved.  The channel may be
% trapezoidal, or circular, and either SI or ES units are accomodated by
% giving the proper value to the acceleration of gravity, g.  If the
% channel is trapezoidal the function "fhydjmpt.m" is utilized to define
% the equation that equates the upstream to the downstream momentum
% function, or if the channel is circular the function "fhydjmpc.m" is
% used. Generally the channel upstream and downstream of the hydraulic jump
% will be the same size; however this script allow for different upstream
% than downstream channel.  So generally you would give b1 & b2 and m1 & m2
% the same values, or D1 & D2 the same values.
% The dialog in the command window use to solve for the conjugate
% depth in both a trapezoidal and circular channel follow:
%>>hydjmp
%Give:g,itype (0=trap.,1=circle) in [ ] [32.2 0]
%Give: 0 if Y1 known, or 1 if Y2 known & this depth in [ ] [1 6]
%Give:Q,b1,m1,b2 & m2 in [ ] [600 10 1.5 10 1.5]
%Conjugate depth =    2.3486
%>>hydjmp
%Give:g,itype (0=trap.,1=circle) in [ ] [9.81 1]
%Give: 0 if Y1 known, or 1 if Y2 known & this depth in [ ] [0 1.5]
%Give:Q,D1 & D2 in [ ] [50 8 8]
%Conjugate depth =    3.4935

var=input('Give:g,itype (0=trap.,1=circle) in [ ] '); g=var(1);itype=var(2);
var=input('Give: 0 if Y1 known, or 1 if Y2 known & this depth in [ ] ');
idown=var(1); 
if idown
    Y2=var(2); Yu=.15*Y2;
else
    Y1=var(2); Yu=5*Y1;
end
if itype
    var=input('Give:Q,D1 & D2 in [ ] ');
    Q=var(1);D1=var(2);D2=var(3);
    if idown
        cosb=1-2*Y2/D2; beta=acos(cosb);A=.25*D2^2*(beta-sin(beta)*cosb);
        Mkn=D2^3/24*(3*sin(beta)-3*beta*cosb-sin(beta)^3)+Q^2/(g*A);
    else
        cosb=1-2*Y1/D1; beta=acos(cosb);A=.25*D1^2*(beta-sin(beta)*cosb);
        Mkn=D1^3/24*(3*sin(beta)-3*beta*cosb-sin(beta)^3)+Q^2/(g*A);
    end
else
    var=input('Give:Q,b1,m1,b2 & m2 in [ ] ');
    Q=var(1); b1=var(2);m1=var(3);b2=var(4);m2=var(5);
    if idown
        A=(b2+m2*Y2)*Y2; Mkn=(b2/2+m2/3*Y2)*Y2^2+Q^2/(g*A);
    else
        A=(b1+m1*Y1)*Y1; Mkn=(b1/2+m1/3*Y1)*Y1^2+Q^2/(g*A);
    end
end
opt=optimset('display','off');
if itype 
    if idown
        Yu=fsolve('fhydjmpc',Yu,opt,g,Mkn,Q,D1);
    else
        Yu=fsolve('fhydjmpc',Yu,opt,g,Mkn,Q,D2);
    end
else
    if idown
        Yu=fsolve('fhydjmpt',Yu,opt,g,Mkn,Q,b1,m1);
    else
        Yu=fsolve('fhydjmpt',Yu,opt,g,Mkn,Q,b2,m2);
    end
end
fprintf('Conjugate depth =%10.4f\n',Yu);
  
