%This script is a conversion of the Fortran Program GUTTER.FOR that solves
%the problem in which a constant inflow comes into a triangular gutter with
%a drain at both of its ends.  The four unknown variables are the critical
%depths at both ends of the gutter, the depth where the flow rate changes
%directions, i.e. where Q=0 and the position x where this occurs.  The 4
%equations being solved are the critical flow equations at both ends of the
%gutter, and the two GVF's one upstream from the position where Q=0, and the
%other downstream from this position.  The function "fgutter.m" provides
%the equations for the MATLAB built-in function "fsolve", and the
%function "dYxgutter.m" provides dY/dx for the built-in ODE solver ode45 to
%solve the differential equations.  The dialog in the command window to
%solve Example Problem 52 in Chapter 4 is as follows:
%>>gutter
%Give: n,So,m,L,g,dx,qs in [ ] [.013 .001 4 800 32.2 20 .011]
%Give guess for Positions Xs 170
%Guesses for x:    0.56     0.94     1.50   170.00
%Yc1 =   0.554, Yc2 =   0.945, Depth at Q=0   0.964, Xs =   166.7
%       x         Y         Q         E         A        Fr
%------------------------------------------------------------
%       0.0     0.554     1.834     0.693     0.614     1.000
%      20.0     0.735     1.614     0.769     1.079     0.435
%      40.0     0.791     1.394     0.810     1.250     0.313
%      60.0     0.831     1.174     0.842     1.380     0.233
%      80.0     0.863     0.954     0.869     1.488     0.172
%     100.0     0.890     0.734     0.893     1.585     0.122
%     120.0     0.915     0.514     0.916     1.673     0.080
%     140.0     0.937     0.294     0.937     1.755     0.043
%     160.0     0.958     0.074     0.958     1.834     0.010
%     166.7     0.964     0.000     0.964     1.860     0.000
%
%       x         Y         Q         E         A        Fr
%------------------------------------------------------------
%     800.0     0.945     6.966     1.181     1.786     1.000
%     780.0     1.117     6.746     1.230     2.495     0.637
%     760.0     1.154     6.526     1.247     2.663     0.569
%      .
%     180.0     0.978     0.146     0.978     1.911     0.019
%     166.7     0.964     0.000     0.964     1.860     0.000

global So m ms qs Cu n hm g g2 g5 L dx gm2 done Xs
var=input('Give: n,So,m,L,g,dx,qs in [ ] ');
n=var(1); So=var(2); m=var(3); L=var(4); g=var(5); dx=var(6);qs=var(7);
done=0; hm=.5*m; ms=1+sqrt(m^2+1); Cu=1; if g>25, Cu=1.486; end; g2=2*g;
g5=.125*g; gm2=g5*m^2;
X(4)=input('Give guess for Positions Xs ');
X(1)=((qs*X(4))^2/gm2)^.2; X(2)=((qs*(L-X(4)))^2/gm2)^.2;X(3)=X(1)+X(2);
fprintf('Guesses for x:%8.2f %8.2f %8.2f %8.2f\n',X);
gm2=m*gm2;  opt=optimset('TolFun',1.e-4);
X=fsolve('fgutter',X,opt);
fprintf('Yc1 =%8.3f, Yc2 =%8.3f, Depth at Q=0%8.3f, Xs =%8.1f\n',X);
done=1;
fgutter(X);