%This script is designed to solve the position of a hydraulic jump
%downstream from a gate, with a downstream water surface, or critical flow
%at the end of the channel.  It uses the second method described in the
%book, e.g. solving the momentum equation simultaneously with two ODE's.
%It performs the same tasks as the programs listed in the text with names
%GVFJMP2.  To accomplish these tasks the MATLAB function "fsolve" is
%utilized to solve the 3 equations, and "ode45" is used to solve the GVF's.
% The dialog in the command window with input and solution for Example 
% Problem 12 in Chapter 4 follows( with a downstream water surface elevation
% of 4.9 ft):
%>>gvfjmp2
%Give: Q,b,m,So,n,L,WS,Yb,g within [ ] [480 8 0 .0011 .013 800 4.9 2 32.2]
%Give guesses for: x,Y1 & Y2 [340 4.5 6.5]
%Critical Depth =    4.8174
%x =    354.89, Y1 =   3.464, Y2 =   6.487
% Plus giving the upstream and downstream GVF-profiles.
global b m So L Yb FNQ QG2 m2 fm2 Cu WS
var=input('Give: Q,b,m,So,n,L,WS,Yb,g within [ ] ');
Q=var(1);b=var(2);m=var(3);So=var(4);n=var(5);L=var(6);WS=var(7);Yb=var(8);g=var(9);
X=input('Give guesses for: x,Y1 & Y2 ');
Cu=1;
if g>20, Cu=1.486; end;  QG2=Q^2/g;  FNQ=n*Q/Cu; m2=2*m; fm2=2*sqrt(m^2+1);
opt=optimset('display','off');
if m<1.e-5
    Yc=((Q/b)^2/g)^.33333333;
else
    Yc=.925*b*(.5*(m^3*Q^2/(g*b^5)))^.284/m;
    Yc=fsolve(inline('QG2*(b+2*m*Yc-((b+m*Yc)*Yc)^.333333','Yc','QG2','b','m'),Yc,opt,QG2,b,m);
end
fprintf('Critical Depth =%10.4f\n',Yc);
if WS<Yc
    fprintf('Depth at end of channel is critical\n');  WS=1.05*Yc;
end
XX=fsolve('fgvfjmp2',X',opt);
fprintf('x =%10.2f, Y1 =%8.3f, Y2 =%8.3f\n',XX');
N=11;  %Number of point to solve GVF profiles
xup=linspace(0,XX(1),N);
[xu,Y1ODE]=ode45('fdyxjmp',xup,Yb);
fprintf(1,'Upsteam GVF-profile\n');
fprintf(1,'      x        Y       Mom.     Fr\n');
for i=1:N
    YY=Y1ODE(i); A=(b+m*YY)*YY; Fr=sqrt(QG2*(b+m2*YY)/A^3);
    MOMU(i)=(b/2+m*YY/3)*YY^2+QG2/A;
    fprintf(1,'%8.2f %9.3f %10.2f %7.2f\n',xup(i),YY,MOMU(i),Fr);
end
xdown=linspace(L,XX(1),N);
[xd,Y2ODE]=ode45('fdyxjmp',xdown,WS);
fprintf(1,'Downsteam GVF-profile\n');
fprintf(1,'      x        Y       Mom.      Fr\n');
for i=1:N
    YY=Y2ODE(i);A=(b+m*YY)*YY; Fr=sqrt(QG2*(b+m2*YY)/A^3);
    MOMD(i)=(b/2+m*YY/3)*YY^2+QG2/A;
    fprintf(1,'%8.2f %9.3f %10.2f %7.2f\n',xdown(i),YY,MOMD(i),Fr);
end