%This script is designed to solve for the water surface profile over the
%length of a side weir, e.g. is performs the same task as GVFSWEIR.FOR.  If
%the depth downstream of the weir is known, then the solution progresses
%from the downstream to the upstream end, and the Qo is the downstream flow
%rate, etc.  The function dYxweir is called on to provide the value of
%dY/dx. An example problem is given below.
%>>gvfsweir
%Give:delx,Yb,Qb,n,So,bo,mo,b2,m2,xbeg,xend,Cd,Yw & g within [ ]
% [-2 5 260 .014 .0008 10 1.5 8 0 40 0 .45 4 32.2]
%Should solution be written to file? 0=no, 1=yes 0
%      x       Y         Q         q*         E        M       b       m
%--------------------------------------------------------------------------
%    40.0     5.000   260.000     2.407     5.656   152.484   8.000   0.000
%    38.0     5.064   265.049     2.642     5.655   157.908   8.100   0.075
%    36.0     5.115   270.524     2.833     5.655   163.494   8.200   0.150
%    34.0     5.155   276.346     2.990     5.654   169.204   8.300   0.225
%    32.0     5.189   282.457     3.121     5.653   175.011   8.400   0.300
%      .
%     6.0     5.359   375.100     3.813     5.637   253.989   9.700   1.275
%     4.0     5.363   382.745     3.832     5.636   260.155   9.800   1.350
%     2.0     5.368   390.428     3.850     5.634   266.323   9.900   1.425
%     0.0     5.371   398.144     3.866     5.633   272.492  10.000   1.500

global bo mo Cd Qo qs1 g db dm Yw Cu xo n So
disp('Give:delx,Yb,Qb,n,So,bo,mo,b2,m2,xbeg,xend,Cd,Yw & g within [ ]')
var=input(' ');
delx=var(1);Yb=var(2);Qb=var(3);n=var(4);So=var(5);bo=var(6);mo=var(7);
b2=var(8);m2=var(9);xbeg=var(10);xend=var(11);Cd=var(12);Yw=var(13);g=var(14);
iout=input('Should solution be written to file? 0=no, 1=yes '); fid=1;
if iout
    filn=input('Give file name within '' '' ');
    fid=fopen(filn,'w');
end
Cu=1; if g>25, Cu=1.486; end;  Cd=2/3*sqrt(2*g)*Cd; db=(b2-bo)/abs(xend-xbeg);
dm=(m2-mo)/abs(xend-xbeg);Q=Qb;Qo=Q;delx5=.5*delx;x=xbeg;b=bo+db*x;m=mo+dm*x;
Y=Yb;  qs1=Cd*(Y-Yw)^1.5; A=(b+m*Y)*Y; Mom=(b/2+m*Y/3)*Y^2+Q^2/(g*A);
E=Y+(Q/A)^2/(2*g);  N=abs(xend-xbeg)/abs(delx);
fprintf(fid,'      x       Y         Q         q*         E        M       b       m\n');
fprintf(fid,'--------------------------------------------------------------------------\n');
fprintf(fid,'%8.1f %9.3f %9.3f %9.3f %9.3f %9.3f %7.3f %7.3f\n',x,Y,Q,qs1,E,Mom,b,m);
for i=1:N
    xz=x+delx; xo=x;
    [xx,YY]=ode45('dYxweir',[x xz],Y);
    Y=YY(size(xx,1));
    qs2=Cd*(Y-Yw)^1.5; Q=Q-delx5*(qs1+qs2); Qo=Q; qs1=qs2; x=xz;
    b=bo+db*x; m=mo+dm*x; A=(b+m*Y)*Y; Mom=(b/2+m*Y/3)*Y^2+Q^2/(g*A);
    E=Y+(Q/A)^2/(2*g);
    fprintf(fid,'%8.1f %9.3f %9.3f %9.3f %9.3f %9.3f %7.3f %7.3f\n',x,Y,Q,qs1,E,Mom,b,m);
end
