%This script solves N branched channel, with the upstream channel receiving
%it water from a reservoir with a head H, and the N-1 downstream channel
%branches from this channel.  It solves the same types of problems that
%SOLBRA.FOR solves.  The input data is essentially the same as used by
%SOLBRA.FOR with the exception that TOL and ERR are not included.The text
%file solbra.txt is an example. See prompt below.  This script uses
%"fsolbra.m" to defined the equations that are solved with MATLAB built-in
%"fsolve", and "fdyxsolbra.m" defines dY/dx for "ode45" to use in solving
%the GVF-proliles.  The function AR is also used to determine the area, and
%when necessary the top widty and wetted perimeter. This "fsolbra"
%"fdyxsolbra" and "AR" are utilized by this script, e.g. they are a
%package.  In solving branched channel systems you must take into account
%that the approach used in this script does not account for the fact that
%critical flow may limit the amount that the upstream channel can supply to
%the downstream channels, and the script will fail if the upstream channel
%doesnot have the capacity to satisfy the needs of the downstream channels.
%The dialog in the command windown to solve the 4 channel system with #2 & #3
%with gates at their ends, and #4 discharging into a reservoir, whose input
%data is given in "solbra.txt" is shown below.
%>>solbra
%The following should be in a file: 1. No of channels,& for each channel
%1-its type, 2-b,3-m,4-n,5-So,6-L,7-Ltras,8-Dz,9-Db,10-Dm,11-KL,12-YG,13-ICTL
% and then H & g, and then guess for Q, Y1 & Y2 for each channel
%Give name of input file 'solbra.txt'
%Should solution be written to a file? (0=no,1=yes) 0
%Solution to    4 Channel at Junction
%--------------------------------------------------------------------------------
% No Ty     b    m    n       So      L     dz    db   dm     Yu     Yd      Q
%--------------------------------------------------------------------------------
%  1  1   8.00 1.50 0.013 0.000800    800  0.00  0.00  0.00  4.529  4.860  355.04
%  2  1   4.00 1.00 0.013 0.000500   1200  0.00  0.00  0.00  5.082  5.533  129.41
%  3  1   5.00 1.00 0.013 0.001000   1000  0.00  0.00  0.00  5.046  5.954  160.57
%  4  3   3.00 0.00 0.013 0.001000    900  0.00  0.00  0.00  4.883  4.500   65.06
  
global NO NO2 NEQS ITYP ICTL n So L LT b m Dz KL Db Dm YG H g g2 Cu 
global PERM TOPW QN Q2G bb mm IPERM NTRAN j
IPERM=0; NTRAN=1;
% ICTL = 1,2 OR 3 for types of downstream controls, gate=1,critical=2,
% reser=3.  YG is depth behind gate for gate; = 0 for critical;res. depth if
% reservoir.   DB and DFM are changes (+ or -) across transition of b and m.
% If uniform flow is to occur in a downstream channel give it a length of
% 10000 or more, and give ICTL=1 (as if a gate is at its end, even though
% this is not the case.
% IN UNKNOWN VECTOR X Q COMES 1ST; UPSTREAM DEPTH NEXT & DOWNSTREAM DEPTH LAST
% i.e. Q(I)=X(I);YU(I)=X(I+NO); YD(I)=X(I+NO2)
disp('The following should be in a file: 1. No of channels,& for each channel');
disp('1-its type, 2-b,3-m,4-n,5-So,6-L,7-Ltras,8-Dz,9-Db,10-Dm,11-KL,12-YG,13-ICTL');
disp(' and then H & g, and then guess for Q, Y1 & Y2 for each channel');
filn=input('Give name of input file ');
fid=fopen(filn,'r');  var=fscanf(fid,'%f'); NO=var(1);j=2; fclose(fid);
for i=1:NO
     ITYP(i)=var(j);b(i)=var(j+1);m(i)=var(j+2);n(i)=var(j+3);So(i)=var(j+4);
   L(i)=var(j+5);LT(i)=var(j+6);Dz(i)=var(j+7);Db(i)=var(j+8);Dm(i)=var(j+9);
   KL(i)=var(j+10);YG(i)=var(j+11);ICTL(i)=var(j+12); j=j+13;
end
NO2=2*NO; NEQS=3*NO;
%H=input('Give H = '); g=input('Give g = '); 
H=var(j); g=var(j+1); g2=2*g; j=j+2;
%disp('For each channel give guesses for: Q, upst Y & downst Y enclosed in [ ]');
for i=1:NO
    X(i)=var(j); X(i+NO)=var(j+1);
    X(i+NO2)=var(j+2); j=j+3;
    KL(i)=(KL(i)+1)/g2;
% you can replace the above 2 lines with the following 2 lines if guesses not given    
%    var1=input(['Channel #' num2str(i) ' ']);
%    X(i)=var1(1); X(i+NO)=var1(2); X(i+NO2)=var1(3);
end
if g>25
    Cu=1.486;
else
    Cu=1;
end
option=optimset('display','off','TolX',1.e-4);
QY=fsolve('fsolbra',X,option);
ii=input('Should solution be written to a file? (0=no,1=yes) ');
if ii
    filno=input('Give this file name in '' '' ');
    fid=fopen(filno);
else
    fid=1;
end
fprintf(fid,'Solution to %4d Channel at Junction\n',NO);
fprintf(fid,'--------------------------------------------------------------------------------\n');
fprintf(fid,' No Ty     b    m    n       So      L     dz    db   dm     Yu     Yd      Q\n');
fprintf(fid,'--------------------------------------------------------------------------------\n');
fmt='%3d %2d %6.2f %4.2f %5.3f %7.6f %6.0f %5.2f %5.2f %5.2f %6.3f %6.3f %7.2f\n'; 
for i=1:NO
fprintf(fid,fmt,i,ICTL(i),b(i),m(i),n(i),So(i),L(i),Dz(i),Db(i),Dm(i),QY(i+NO),QY(i+NO2),QY(i));
end
if fid ~= 1, fclose(fid); end;