% This script solves the flow in a channel feed by an upstream reservoir,
% with a trasition at its downstream end, where the specific energy is
% specified.  It differs from script "solgvfa.m" in that the flow is not
% critical at the downstream end.  Thus four equations are solved for four
% unknowns, e.g. Q,Y1,Y2 and Y3 (the depth associated with the given energy.
%The Froude Number is printed out associated with Y3.  Should this Fr3 be
%larger than unity, the solution is not valid, and critical flow at the
%downstream end governs, e.g. script "solgvfa.m" should be used, or a
%variation of it that does not require that the break-in grade occurs at
%the beginning of a rectangular channel.  An example problem follows:\
%>>solgvfde
%Give:b1,m1,n,So,b2,m2,E2,H,L,KL,KE,g in [ ] [10 2 .015 .0002 20 0 4.8 5 1000 .05 .05 32.2]
%Give guesses for: Q,Y1,Y2 & Y3 in [ ] [300 4.8 4.7 4.7]
%Q =    566.46 Y1 =     3.511 Y2 =     3.486 Y3 =     4.092 Fr3 =    0.60

global b1 m1 n So b2 m2 E2 H L KL KE1 Cu g g2 Q2G QN
var=input('Give:b1,m1,n,So,b2,m2,E2,H,L,KL,KE,g in [ ] ');
b1=var(1);m1=var(2);n=var(3);So=var(4);b2=var(5);m2=var(6);E2=var(7);
H=var(8);L=var(8);KL=(1+var(10));KE1=(1+var(11));g=var(12);  
Cu=1.; g2=2*g; if g>20, Cu=1.486; end;
X=input('Give guesses for: Q,Y1,Y2 & Y3 in [ ] ');
option=optimset('display','off','TolX',1.e-4);
XX=fsolve('fsolgvfde',X,option);
Fr3=sqrt(XX(1)^2*(b2+2*m2*XX(4))/(g*((b2+m2*XX(4))*XX(4))^3));
fprintf('Q =%10.2f Y1 =%10.3f Y2 =%10.3f Y3 =%10.3f Fr3 =%8.2f\n',XX,Fr3);