% This script solves the flow in a channel feed by an upstream reservoir,
% with a trasition at its downstream end, where the specific energy is
% specified.  It differs from script "solgvfde.m" in that there is a check
% to see if the depth at the downstream end of the transition is above
% critical depth.  If not then critical depth becomes the first equation
% rather than the energy equation that E2 =Yend+Q^2/(2gAend^2). 
% Four equations are solved for four unknowns, e.g. Q,Y1,Y2 and Y3
% (the depth associated with the given energy.
% The Froude Number is printed out associated with Y3.  A couple of examples
% using solgvfdec follow, the first has subcritical flow at end, the 
% second has critical flow at the end.
%>>solgvfdec
%Give:b1,m1,n,So,b2,m2,E2,H,L,KL,KE,g in [ ] [10 2 .013 .0005 16 2 4.8 5 1500 .05 .05 32.2]
%Give guesses for: Q,Y1,Y2 & Y3 in [ ] [550 4.2 4.2 3.5]
%Q =    557.52 Y1 =     3.364 Y2 =     3.347 Y3 =     4.441 Fr3 =    0.49
%>>solgvfdec
%Give:b1,m1,n,So,b2,m2,E2,H,L,KL,KE,g in [ ] [10 2 .013 .0005 13 1 4.8 5 1500 .05 .05 32.2]
%Give guesses for: Q,Y1,Y2 & Y3 in [ ] [450 4.6 4.6 3.2]
%Q =    545.13 Y1 =     4.174 Y2 =     4.170 Y3 =     3.394 Fr3 =    1.03

global b1 m1 n So b2 m2 E2 H L KL KE1 Cu g g2 Q2G QN
var=input('Give:b1,m1,n,So,b2,m2,E2,H,L,KL,KE,g in [ ] ');
b1=var(1);m1=var(2);n=var(3);So=var(4);b2=var(5);m2=var(6);E2=var(7);
H=var(8);L=var(8);KL=(1+var(10));KE1=(1+var(11));g=var(12);  
Cu=1.; g2=2*g; if g>20, Cu=1.486; end;
X=input('Give guesses for: Q,Y1,Y2 & Y3 in [ ] ');
option=optimset('display','off','TolX',1.e-4);
XX=fsolve('fsolgvfdec',X,option);
Fr3=sqrt(XX(1)^2*(b2+2*m2*XX(4))/(g*((b2+m2*XX(4))*XX(4))^3));
fprintf('Q =%10.2f Y1 =%10.3f Y2 =%10.3f Y3 =%10.3f Fr3 =%8.2f\n',XX,Fr3);