%This script is a conversion of the Fortran Program SOLJMP2.FOR and as such
%is designed to solve a three channel system such as Example Problem 33 in
%Chapter 4, in which a supercritical flow occurs upstream in Channel 1,
%which after a hydraulic jump branches into Channel 2 and 3, with a
%constant water surface elevation at the end of Channel 2 and a gate at the
%end of Channel 3.  The file 'SOLJMP2.TXT' contains the information to
%describe Example Problem 33.  The dialog in the command window to solve
%this Ex. Prb. consists of the following:
%>>soljmp2
%Give file that contains input data within ' ' 'SOLJMP2.TXT'
%Give guess for:
%Q2 = 440
%Q3 = 160
%Y1 = 6.6
%Y21= 6.7
%Y31= 7
%Y32= 8.5
%Y1u= 2.3
%Y1d= 6.1
%x  = 300
%Solution:
%Q2    437.9782
%Q3    162.0218
%Y1      6.7342
%Y21     6.6107
%Y31     6.9810
%Y32     8.5335
%Y1u     2.2694
%Y1d     6.1411
%x     298.6369

global b m n So L g g2 Cu QN QSG Q1 Y4 A4 H2 Yo bb mm SSo
unk='Q2 Q3 Y1 Y21Y31Y32Y1uY1dx  ';
filn=input('Give file that contains input data within '' '' ');
fid=fopen(filn,'r');
var=fscanf(fid,'%f');   fclose(fid); 
for i=1:3
    j=5*(i-1)+1;
    b(i)=var(j); m(i)=var(j+1);n(i)=var(j+2);So(i)=var(j+3);L(i)=var(j+4);
end
Q1=var(j+5);Y4=var(j+6);H2=var(j+7);g=var(j+8);Yo=var(j+9);  Cu=1;
if g>25, Cu=1.486; end;  g2=2*g; A4=g2*((b(3)+m(3)*Y4)*Y4)^2;
disp('Give guess for:');   j=0;
for i=1:3:25
    j=j+1;
    X(j)=input([unk(i:i+2) '= ']);
end
opt=optimset('display','off','TolX',1e-4,'MaxIter',30);
X=fsolve('fsoljmp2',X,opt);   j=0;  disp('Solution:');
for i=1:3:25
    j=j+1;
    fprintf(1,'%3s %10.4f\n',unk(i:i+2),X(j));
end
    