%This script solves problems in which a specified inflow/outflow occurs
%within a middle portion of a channel.  The channel gets it supply from a
%reservoir with a head H, and depending upon the downstream boundary
%condition IBC=1, there is a gate, IBC=2 critical flow, and IBC=3 a known
%water surface elevation.  IQT identifies the nature of the lateral
%inflow/outflow.  In brief this script solves the same type of problems
%that the Fortran program SOLSID.FOR handles.  It used the function
%"fsolsid.m" to define the equations for the MATLAB built-in "fsolve" to
%solve, and when solving the differential equation, which is done in three
%parts, the function "fdYdxsolsid.m" is called on to supply the derivative
%dY/dx. The MATLAB differential equation solve ode45 is used to solve the
%differential eq. The text file "solsid.txt" contains the input data to solve
%Homework Problem 149 in Chapter 4.  The dialog in the command window to
%solve this problem follows:
%>>solsid
%Give name of INPUT file in '  '  'solsid.txt'
%Q =     54.69, Y1 =      2.83, Y2 =      5.33, Qe =     39.69
%Give Del x for sol. of x & Y values 50
%Should profile be written to file? 0=no,1=yes 0
% 2230.0000    5.3342
% 2180.0000    5.2745
%  .
%  680.0000    3.4964
%  630.0000    3.4382
%  625.0000    3.4140
%   . 
%  600.0000    3.2886
%  550.0000    3.2491
%   .
%   50.0000    2.8666
%    0.0000    2.8300
    
global b1 m1 n1 So1 b2 m2 n2 So2 Ke KL g g2 A3 H Qe L1 Le Lt Sot Cu Y3 Uqx ...
   L db dm qss IQT IBC Qb
filn=input('Give name of INPUT file in ''  ''  ');
fid=fopen(filn,'r');
var=fscanf(fid,'%f');
% input is the same as with Fortran program with the first 2 items TOL &
% ERR omitted.
fclose(fid);
n1=var(1);So1=var(2);b1=var(3);m1=var(4);L1=var(5);n2=var(6);So2=var(7);
b2=var(8);m2=var(9);L2=var(10);b3=var(11);Lt=var(12);Sot=var(13);
H=var(14);qss=var(15);g=var(16);KL=(1+var(17));Ke=(1+var(18));Y3=var(19);
Uq=var(20);ANGLE=var(21);IQT=var(22);IBC=var(23); X(1)=var(24); Qb=X(1);
X(2)=var(25); X(3)=var(26);  Cu=1; g2=2*g;  A3=(Y3*b3)^2*g2;
db=(b2-b1)/Lt; dm=(m2-m1)/Lt; Uqx=Uq*cos(.17455329*ANGLE);
Le=L1+Lt; L=Le+L2; if g>30, Cu=1.486; end;
X=fsolve('fsolsid',X);
Qe=X(1)+qss*Lt;
fprintf(1,'Q =%10.2f, Y1 =%10.2f, Y2 =%10.2f, Qe =%10.2f\n',X,Qe);
delx=input('Give Del x for sol. of x & Y values ');
if delx>0.01
    ij=input('Should profile be written to file? 0=no,1=yes '); fid=1;
    if ij
    filno=input('Give file name for output ');
    fid=fopen(filno,'w');
    fprintf(fid,'Q =%10.2f, Y1 =%10.2f, Y2 =%10.2f, Qe =%10.2f\n',X,Qe);
    end
    xx=L; Y=X(3);fprintf(fid,'%10.4f %9.4f\n',xx,Y);
    while xx>.01
        if (xx <= Le) & (xx > L1)
            xz=xx-0.1*delx;
        else
            xz=xx-delx;
        end
        [x1,Y1]=ode45('fdYdxsolsid',[xx xz],Y);
        Y=Y1(size(x1,1));
        fprintf(fid,'%10.4f %9.4f\n',xz,Y);
        xx=xz;
    end
    if ij, fclose(fid); end;
end
    