% Solves UCW with upstream gate instantly raised with uniform flow downstream
%  Uses the implicit method
% That is this script accomplishes the same tasks as Program WAVEUCI.FOR
% listed in the text. It utilizes the Runge-Kutta solver described in
% Appendix c RUKUSTP to the solve ODE equation in the system of 4
% equations.  The reason RUKUSTP is used rather than RUKUST is that
% parameters namely the unknown vector X needs to be passed from the ODE
% solver to the function dywave that provides the derivative dY/dx.  The
% input to solve example Problem 71 in Chapter 4 is as follows:
%>>waveuci
%Give: g,b,m,n,So,Qo & Guess for Yo enclosed in [ ] [32.2 10 1.5 .013 .0005 250 3.4]
%Give file name for output within ' ' 'waveuci.out'
%Qo =   250.0, Normal Depth =   3.563, Vo =   4.573
%Give: New Q2,Dt,NT & Guess for Yb within [ ] [500 5 25 4.3]
%For New Q =  500.00, Starting Depth Yb =   4.302, A =   70.78, Celerity =   9.975,Wave V =  15.514
%global b m m2 ms m3 bh Yb Vo Ao hca1 g Qb xpos cun So dt5 wv1 dxs
%The output is given in the file 'waveuci.out'

var=input('Give: g,b,m,n,So,Qo & Guess for Yo enclosed in [ ] ');
g=var(1);b=var(2);m=var(3);n=var(4);So=var(5);Qo=var(6);Yo=var(7);
bh=.5*b; m3=m/3.; m2=2.*m; ms=2.*sqrt(m^2+1.); Cu=1;
if g>25, Cu=1.486; end; 
cun=n/Cu; QN=n*Qo; cus=Cu*sqrt(So); opt=optimset('display','off');
Yo=fsolve(inline('QN*(b+ms*Yo)^.6666667-cus*((b+m*Yo)*Yo)^1.6666667','Yo','QN','b','m','ms','cus'),...
    Yo,opt,QN,b,m,ms,cus);
Ao=(b+m*Yo)*Yo; Vo=Qo/Ao; hca1=(bh+m3*Yo)*Yo^2;
filn=input('Give file name for output within '' '' ');
fid=fopen(filn,'w');
fprintf(1,'Qo =%8.1f, Normal Depth =%8.3f, Vo =%8.3f\n',Qo,Yo,Vo);
fprintf(fid,'Qo =%8.1f, Normal Depth =%8.3f, Vo =%8.3f\n',Qo,Yo,Vo);
va1=input('Give: New Q2,Dt,NT & Guess for Yb within [ ] ');
Qb=va1(1);Dt=va1(2); NT=va1(3); Yb=va1(4);
dt5=.5*Dt; hc1=hca1/Ao; yy=Yb;
Yb=fsolve('fYb',yy,opt,hc1,Qo);
A=(b+m*Yb)*Yb; c=sqrt(abs(g*A/(b+m2*Yb)));X(1)=(Qb-Qo)/(A-Ao);
fprintf(1,'For New Q =%8.2f, Starting Depth Yb =%8.3f, A =%8.2f, Celerity =%8.3f,Wave V =%8.3f\n',...
   Qb,Yb,A,c,X(1));
fprintf(fid,'For New Q =%8.2f, Starting Depth Yb =%8.3f, A =%8.2f, Celerity =%8.3f,Wave V =%8.3f\n',...
   Qb,Yb,A,c,X(1));
X(1)=(Qb-Qo)/(A-Ao); X(2)=Yb; X(3)=Qb; X(4)=Dt*X(1);  
fprintf(1,' Time wave V.     Y2     Q2       x      Fr1     Fr2\n');
fprintf(fid,' Time wave V.     Y2     Q2       x      Fr1     Fr2\n');
fprintf(1,'-----------------------------------------------------\n');
fprintf(fid,'-----------------------------------------------------\n');
Fr1=(X(1)-Vo)/sqrt(g*Ao/(b+m2*Yo));Fr2=(X(1)-Qb/A)/sqrt(g*A/(b+m2*Yb));
fprintf(1,'%5d %7.3f %7.3f %7.2f %7.1f %7.3f %7.3f\n',0,X(1),Yb,Qb,0,Fr1,Fr2);
fprintf(fid,'%5d %7.3f %7.3f %7.2f %7.1f %7.3f %7.3f\n',0,X(1),Yb,Qb,0,Fr1,Fr2);
 xpos=0.; wv1=X(1); opt=optimset('display','off','TolFun',1e-4); dxs=.5;
for k=1:NT
    X=fsolve('fwaveuci',X,opt);
    A=(b+m*X(2))*X(2); Fr1=(X(1)-Vo)/sqrt(g*Ao/(b+m2*Yo));
    Fr2=(X(1)-X(3)/A)/sqrt(g*A/(b+m2*X(2)));
    fprintf(1,'%5.0f %7.3f %7.3f %7.2f %7.1f %7.3f %7.3f\n',Dt*k,X,Fr1,Fr2);
    fprintf(fid,'%5.0f %7.3f %7.3f %7.2f %7.1f %7.3f %7.3f\n',Dt*k,X,Fr1,Fr2);
    wv1=X(1); xpos=X(4); X(4)=X(4)+Dt*wv1; 
end
    