% Solves UCW with upstream gate instantly raised with uniform flow downstream
%  Uses the implicit method
% This script does the same tasks as program WAVEUCI.FOR, or in other words
% it uses the implicit method to solve the 4 equations that describe
% movement of wave cause by a sudden increase in the flow rate.  It is a
% variation of script waveuci.m.  The former uses the Runge-Kutta function
% rukustp (see Appendix c) to solve the ODE, whereas this script using the
% MATLAB built-in function ode45 to obtain this solution.  This script sets
% up the Jacobian matrix, and uses back division to obtain the solution
% that provides the correction to the unknowns for each iteration.  In other
% words it uses the built in matrix solving capabilities of MATLAB rather
% than call on a linear algebra solver as does the Fortran program.
% This script uses fwaveuco.m to provide the values of the equations, and
% dywaveo.m provides the differential equation to ode45.  Also fYbo.m is
% used to obtain the beginning depth Yb.
% To solve Example Problem 71 in Chapter 4 the following input is given to
% this program.  (Notice that there are extra fprintf statement in this
% script so you can following how the solution is proceeding.  You might
% want to remove this, or add additional ones.)
%>>waveuco
%Give: g,b,m,n,So,Qo & Guess for Yo enclosed in [ ] [32.2 10 1.5 .013 .0005 250 3.4]
%Give file name for output within ' ' 'waveuco.out'
%Qo =   250.0, Normal Depth =   3.563, Vo =   4.573
%Give: New Q2,Dt,NT & Guess for Yb within [ ] [500 5 25 4.3]
    
global b m m2 ms m3 bh Yb Vo Ao hca1 g Qb xpos cun So dt5 wv1
var=input('Give: g,b,m,n,So,Qo & Guess for Yo enclosed in [ ] ');
g=var(1);b=var(2);m=var(3);n=var(4);So=var(5);Qo=var(6);Yo=var(7);
bh=.5*b; m3=m/3.; m2=2.*m; ms=2.*sqrt(m^2+1.);g2=2*g; Cu=1;
if g>25, Cu=1.486; end; 
cun=n/Cu; QN=n*Qo; cus=Cu*sqrt(So); opt=optimset('display','off');
Yo=fsolve(inline('QN*(b+ms*Yo)^.6666667-cus*((b+m*Yo)*Yo)^1.6666667','Yo','QN','b','m','ms','cus'),...
    Yo,opt,QN,b,m,ms,cus);
Ao=(b+m*Yo)*Yo; Vo=Qo/Ao; hca1=(bh+m3*Yo)*Yo^2;
filn=input('Give file name for output within '' '' ');
fid=fopen(filn,'w');
fprintf(1,'Qo =%8.1f, Normal Depth =%8.3f, Vo =%8.3f\n',Qo,Yo,Vo);
fprintf(fid,'Qo =%8.1f, Normal Depth =%8.3f, Vo =%8.3f\n',Qo,Yo,Vo);
va1=input('Give: New Q2,Dt,NT & Guess for Yb within [ ] ');
Qb=va1(1);Dt=va1(2); NT=va1(3); Yb=va1(4);
dt5=.5*Dt; hc1=hca1/Ao; yy=Yb;
Yb=fsolve('fYbo',yy,opt,hc1,Qo);
A=(b+m*Yb)*Yb;hca2=(bh+m3*Yb)*Yb^2;c=sqrt(abs(g*A/(b+m2*Yb)));X(1)=(Qb-Qo)/(A-Ao);
fprintf(1,'For New Q =%8.2f, Starting Depth Yb =%8.3f, A =%8.2f, Celerity =%8.3f,Wave V =%8.3f\n',...
   Qb,Yb,A,c,X(1));
fprintf(fid,'For New Q =%8.2f, Starting Depth Yb =%8.3f, A =%8.2f, Celerity =%8.3f,Wave V =%8.3f\n',...
   Qb,Yb,A,c,X(1));
X(1)=(Qb-Qo)/(A-Ao); X(2)=Yb; X(3)=Qb; X(4)=Dt*X(1); 
fprintf(1,' Time wave V.     Y2     Q2       x      Fr1     Fr2\n');
fprintf(fid,' Time wave V.     Y2     Q2       x      Fr1     Fr2\n');
fprintf(1,'-----------------------------------------------------\n');
fprintf(fid,'-----------------------------------------------------\n');
Fr1=(X(1)-Vo)/sqrt(g*Ao/(b+m2*Yo));Fr2=(X(1)-Qb/A)/sqrt(g*A/(b+m2*Yb));
fprintf(1,'%5d %7.3f %7.3f %7.2f %7.1f %7.3f %7.3f\n',0,X(1),Yb,Qb,0,Fr1,Fr2);
fprintf(fid,'%5d %7.3f %7.3f %7.2f %7.1f %7.3f %7.3f\n',0,X(1),Yb,Qb,0,Fr1,Fr2);
 xpos=0.; wv1=X(1); 
for k=1:NT
    nct=0; sum=1;
    while (nct<20) & (sum>1.e-5)
       sum=0; f=fwaveuci(X);
        for i=1:4
         xx=X(i); X(i)=1.005*X(i); f1=fwaveuci(X);
         for j=1:4, d(j,i)=(f1(j)-f(j))/(X(i)-xx); end;
         X(i)=xx;
        end
       sol=d\f';  nct=nct+1;
       for i=1:4, X(i)=X(i)-sol(i); sum=sum+abs(sol(i)); end;
       disp(['k=' num2str(k) ', NCT=' num2str(nct) ', SUM=' num2str(sum)]);
    end
    A=(b+m*X(2))*X(2); Fr1=(X(1)-Vo)/sqrt(g*A/(b+m2*Yo));
    Fr2=(X(1)-X(3)/A)/sqrt(g*A/(b+m2*X(2)));
    fprintf(1,'%5.0f %7.3f %7.3f %7.2f %7.1f %7.3f %7.3f\n',Dt*k,X,Fr1,Fr2);
    fprintf(fid,'%5.0f %7.3f %7.3f %7.2f %7.1f %7.3f %7.3f\n',Dt*k,X,Fr1,Fr2);
    wv1=X(1); xpos=X(4); X(4)=X(4)+Dt*wv1;
end
    