C This program is designed to solve a systems of N branched channels with N-1
C downstream channel from 1 upstream channel. Read the comments below regarding
C preparation of input data to define the system.  The approach used in this 
C Program assumes that the upstream channel can supply the needs of the
C downstream without the flow becoming critical, e.g. no provision is used
C to limit the flow into the downstream channel due to critical flow in the
C upstream channel. 
C This program is very similiar to SOLBRA.FOR with the exception that it is
C computationally more efficient.  Rather than generating a lot of zeros in
C the Jacobian matrix by solving the equations twice, it automatically assigns
C a zero to those elements whose equations (rows) do not contain the variable
C associated with a column of the matrix.  
      PARAMETER (N=12,M=36,MM=1296)
      LOGICAL*2 IPERM,NTRAN
      LOGICAL*1 NZERO(M,M)
      REAL F(M),D(M,M),FN(N),SO(N),L(N),LT(N),B(N),FM(N),DZ(N),KL(N),
     & DB(N),DFM(N),YG(N),X(M)
      INTEGER*2 INDX(M),ITYP(N),ICTL(N)
      COMMON NGOOD,NBAD,KMAX,KOUNT,DXSAVE
      COMMON /TRAS/NO,NO2,NEQS,ITYP,ICTL,FN,SO,L,LT,B,FM,DZ,KL,DB,DFM,YG
     &,X,H,G,G2,CC,TOL,PERM,TOPW,QN,Q2G,BB,FMM,IPERM,NTRAN,JI
      DATA IN,IOUT/2,3/,NZERO/MM*.FALSE./
      IPERM=.FALSE.
      NTRAN=.TRUE.
C ICTL = 1,2 OR 3 for types of downstream controls, gate=1,critical=2,
C reser=3.  YG is depth behind gate for gate; = 0 for critical;res. depth if
C reservoir.   DB and DFM are changes (+ or -) across transition of b and m.
C IN UNKNOWN VECTOR X Q COMES 1ST; UPSTREAM DEPTH NEXT & DOWNSTREAM DEPTH LAST
C i.e. Q(I)=X(I);YU(I)=X(I+NO); YD(I)=X(I+NO2)
      READ(IN,*) NO,(ITYP(I),B(I),FM(I),FN(I),SO(I),L(I),LT(I),DZ(I),
     &DB(I),DFM(I),KL(I),YG(I),ICTL(I),I=1,NO)
      NO2=2*NO
      NEQS=3*NO
      NZERO(1,1)=.TRUE.
      NZERO(1,NO+1)=.TRUE.
      DO 2 I=2,NO
      NZERO(I,1)=.TRUE.
      NZERO(I,I)=.TRUE.
      NZERO(I,I+NO)=.TRUE.
2     NZERO(I,NO2+1)=.TRUE.
      DO 4 I=NO+1,NO2
      NZERO(I,I-NO)=.TRUE.
      NZERO(I,I)=.TRUE.
4     NZERO(I,I+NO)=.TRUE.
      DO 6 I=1,NO
6     NZERO(NO2+1,I)=.TRUE.
      DO 8 I=NO2+2,NEQS
      NZERO(I,I-NO2)=.TRUE.
8     NZERO(I,I)=.TRUE.
      READ(IN,*) TOL,ERR,H,G
      READ(IN,*) (X(I),X(I+NO),X(I+NO2),I=1,NO)  ! GUESSES
      IF(G.GT. 30.) THEN
      CC=1.486
      ELSE
      CC=1.
      ENDIF
      G2=2.*G
      DO 10 I=1,NO
10    KL(I)=(KL(I)+1.)/G2
      NCT=0
20    DO 30 I=1,NEQS
      F(I)=FUN(I)
      DO 30 J=1,NEQS
      IF(NZERO(I,J)) THEN
      DX=.005*X(J)
      X(J)=X(J)+DX
      D(I,J)=(FUN(I)-F(I))/DX
      X(J)=X(J)-DX
      ELSE
      D(I,J)=0.
      ENDIF
30    CONTINUE
      CALL SOLVEQ(NEQS,1,M,D,F,1,DD,INDX)
      DIF=0.
      DO 40 I=1,NEQS
      X(I)=X(I)-F(I)
40    DIF=DIF+ABS(F(I))
      NCT=NCT+1
      WRITE(*,*)' NCT=',NCT,DIF
      IF(NCT.LT.30 .AND. DIF.GT.ERR) GO TO 20
      WRITE(IOUT,100) NO
100   FORMAT(' Solution to',I3,' Channel at Junction',/,1X,79('-'),/,
     &' No Ty      b    m     n      So      L    dz    db    dm     Yu
     &   Yd       Q',/,1X,79('-'))
      DO 50 I=1,NO
50    WRITE(IOUT,110) I,ICTL(I),B(I),FM(I),FN(I),SO(I),L(I),DZ(I),DB(I),
     &DFM(I),X(I+NO),X(I+NO2),X(I)
110   FORMAT(I3,I3,F7.2,F5.2,F6.3,F8.6,F7.0,3F6.2,2F7.3,F8.2)
      END
      FUNCTION FUN(II)
      PARAMETER (N=12,M=36)
      EXTERNAL DYX
      LOGICAL*2 IPERM,NTRAN
      REAL FN(N),SO(N),L(N),LT(N),B(N),FM(N),DZ(N),KL(N),DB(N),DFM(N),
     &YG(N),X(M),Y(1),DY(1),W(1,13),XP(1),YP(1,1)
      INTEGER*2 ITYP(N),ICTL(N)
      COMMON NGOOD,NBAD,KMAX,KOUNT,DXSAVE
      COMMON /TRAS/NO,NO2,NEQS,ITYP,ICTL,FN,SO,L,LT,B,FM,DZ,KL,DB,DFM,YG
     &,X,H,G,G2,CC,TOL,PERM,TOPW,QN,Q2G,BB,FMM,IPERM,NTRAN,JI
      H1=-.05
      HMIN=.001
      IF(II.EQ.1) THEN
      FUN=H-X(NO+1)-KL(1)*(X(1)/AR(1,X(NO+1)))**2
      ELSE IF(II.GT.1 .AND. II.LE.NO) THEN
      FUN=X(NO2+1)+(X(1)/AR(1,X(NO2+1)))**2/G2-X(NO+II)-KL(II)*(X(II)/
     &AR(II,X(NO+II)))**2
      ELSE IF(II.GT.NO .AND. II.LE.NO2) THEN
      JI=II-NO
      IF(L(JI).LT.10000.) THEN
      XX=L(JI)+LT(JI)-1.E-5
      XZ=0.
      IPERM=.TRUE.
      Y(1)=X(NO2+JI)
      IF(ICTL(JI).EQ.2) Y(1)=1.1*Y(1)
      QN=(FN(JI)*X(JI)/CC)**2
      Q2G=X(JI)**2/G
      CALL ODESOL(Y,DY,1,XX,XZ,TOL,H1,HMIN,1,XP,YP,W,DYX)
      FUN=X(NO+JI)-Y(1)
      ELSE
      AA=AR(JI,X(NO+JI))
      FUN=X(JI)-CC/FN(JI)*AA*(AA/PERM)**.6666667*SQRT(SO(JI))
      ENDIF
      ELSE IF(II.EQ.NO2+1) THEN
      FUN=X(1)
      DO 20 I=2,NO
20    FUN=FUN-X(I)
      ELSE
      JI=II-NO2
      NTRAN=.FALSE.
      XX=L(JI)+LT(JI)-1.E-5
      IF(LT(JI).LT. 0.1) THEN
      BB=B(JI)
      FMM=FM(JI)
      ELSE
      BB=B(JI)+DB(JI)
      FMM=FM(JI)+DFM(JI)
      ENDIF
      IF(ICTL(JI).EQ.1) THEN
      IF(L(JI).LT.10000.) THEN
      FUN=X(NO2+JI)+(X(JI)/AR(JI,X(NO2+JI)))**2/G2-YG(JI)-KL(JI)*(X(JI)/
     &AR(JI,YG(JI)))**2
      ELSE
      FUN=X(NO2+JI)-X(NO+JI)
      ENDIF
      NTRAN=.FALSE.
      ELSE IF(ICTL(JI).EQ.2) THEN
      AA=AR(JI,X(NO2+JI))
      IPERM=.FALSE.
      FUN=X(JI)**2*TOPW-G*AA**3
      ELSE
      FUN=X(NO2+JI)-YG(JI)
      ENDIF
      NTRAN=.TRUE.
      ENDIF
      RETURN
      END
      FUNCTION AR(I,YY)
      PARAMETER (N=12,M=36)
      LOGICAL*2 IPERM,NTRAN
      REAL FN(N),SO(N),L(N),LT(N),B(N),FM(N),DZ(N),KL(N),DB(N),DFM(N),
     & YG(N),X(M)
      INTEGER*2 ITYP(N),ICTL(N)
      COMMON /TRAS/NO,NO2,NEQS,ITYP,ICTL,FN,SO,L,LT,B,FM,DZ,KL,DB,DFM,YG
     &,X,H,G,G2,CC,TOL,PERM,TOPW,QN,Q2G,BB,FMM,IPERM,NTRAN,JI
      IF(ITYP(I).EQ.1) THEN
      IF(NTRAN) THEN
      BB=B(I)
      FMM=FM(I)
      ENDIF
      AR=(BB+FMM*YY)*YY
      IF(IPERM) THEN
      PERM=BB+2.*YY*SQRT(1.+FMM*FMM)
      TOPW=BB+2.*FMM*YY
      ENDIF
      ELSE
      COSB=1.-2.*YY/B(I)
      BETA=ACOS(COSB)
      AR=.25*B(I)**2*(BETA-SIN(BETA)*COSB)
      IF(IPERM) THEN
      PERM=BETA*B(I)
      TOPW=B(I)*SIN(BETA)
      ENDIF
      ENDIF
      RETURN
      END
      SUBROUTINE DYX(XX,Y,DY)
      PARAMETER (N=12,M=36)
      LOGICAL*2 IPERM,NTRAN
      REAL FN(N),SO(N),L(N),LT(N),B(N),FM(N),DZ(N),KL(N),DB(N),DFM(N),
     & YG(N),X(M),Y(1),DY(1)
      INTEGER*2 ITYP(N),ICTL(N)
      COMMON /TRAS/NO,NO2,NEQS,ITYP,ICTL,FN,SO,L,LT,B,FM,DZ,KL,DB,DFM,YG
     &,X,H,G,G2,CC,TOL,PERM,TOPW,QN,Q2G,BB,FMM,IPERM,NTRAN,JI
      IF(XX.LE.L(JI)) THEN
      NTRAN=.TRUE.
      DAX=0.
      ELSE
      NTRAN=.FALSE.
      FLEN=(XX-L(JI))/LT(JI)
      BB=B(JI)+FLEN*DB(JI)
      FMM=FM(JI)+FLEN*DFM(JI)
      DAX=X(JI)**2/G*Y(1)*(DB(JI)+Y(1)*DFM(JI))/LT(JI)
      ENDIF
      AA=AR(JI,Y(1))
      A3=AA**3
      SF=QN*(ABS(PERM/AA)**.666666667/AA)**2
      DY(1)=(SO(JI)-SF+DAX/A3)/(1.-Q2G*TOPW/A3)
      RETURN
      END
      
      
